==> jc-1.4.0.tar.gz: soot/dava/internal/SET/SETIfElseNode.h <==
// public class soot.dava.internal.SET.SETIfElseNode

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5fe8043c911a8f07 soot_dava_internal_SET_SETControlFlowNode
// @dep_class 1df4134650bc1e83 soot_dava_internal_SET_SETDagNode
// @dep_class 847c84439c35c0f soot_dava_internal_SET_SETIfElseNode
// @dep_class 4d3d060182af30b5 soot_dava_internal_SET_SETNode

// header file dependencies
// @dep_header soot_dava_internal_SET_SETDagNode

#include "soot/dava/internal/SET/SETDagNode.h"

#ifndef _JC_soot_dava_internal_SET_SETIfElseNode_H_
#define _JC_soot_dava_internal_SET_SETIfElseNode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_dava_internal_AST_ASTNode$object;
struct _jc_soot_dava_internal_asg_AugmentedStmt$object;
struct _jc_soot_util_IterableSet$object;

// Typedefs
typedef struct _jc_soot_dava_internal_SET_SETIfElseNode$sub_refs	_jc_soot_dava_internal_SET_SETIfElseNode$sub_refs;
typedef struct _jc_soot_dava_internal_SET_SETIfElseNode$sub_nonrefs	_jc_soot_dava_internal_SET_SETIfElseNode$sub_nonrefs;
typedef struct _jc_soot_dava_internal_SET_SETIfElseNode$refs	_jc_soot_dava_internal_SET_SETIfElseNode$refs;
typedef struct _jc_soot_dava_internal_SET_SETIfElseNode$nonrefs	_jc_soot_dava_internal_SET_SETIfElseNode$nonrefs;
typedef struct _jc_soot_dava_internal_SET_SETIfElseNode$object	_jc_soot_dava_internal_SET_SETIfElseNode$object;

typedef const struct _jc_soot_dava_internal_SET_SETIfElseNode$vmethods	_jc_soot_dava_internal_SET_SETIfElseNode$vmethods;
typedef const struct _jc_soot_dava_internal_SET_SETIfElseNode$vtable	_jc_soot_dava_internal_SET_SETIfElseNode$vtable;
typedef const struct _jc_soot_dava_internal_SET_SETIfElseNode$vtype	_jc_soot_dava_internal_SET_SETIfElseNode$vtype;

// Constructors
extern void _jc_soot_dava_internal_SET_SETIfElseNode$method$_init$bff09806e2e9995e(_jc_env *, struct _jc_soot_dava_internal_SET_SETIfElseNode$object *, struct _jc_soot_dava_internal_asg_AugmentedStmt$object *, struct _jc_soot_util_IterableSet$object *, struct _jc_soot_util_IterableSet$object *, struct _jc_soot_util_IterableSet$object *);

// Virtual methods
extern struct _jc_soot_dava_internal_AST_ASTNode$object *_jc_soot_dava_internal_SET_SETIfElseNode$method$emit__5fAST$9abd6bb299fe14c5(_jc_env *, struct _jc_soot_dava_internal_SET_SETIfElseNode$object *);
extern struct _jc_soot_util_IterableSet$object *_jc_soot_dava_internal_SET_SETIfElseNode$method$get__5fNaturalExits$93615053d2db173e(_jc_env *, struct _jc_soot_dava_internal_SET_SETIfElseNode$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_SET_SETIfElseNode$method_info$emit__5fAST$9abd6bb299fe14c5;
extern _jc_method _jc_soot_dava_internal_SET_SETIfElseNode$method_info$get__5fNaturalExits$93615053d2db173e;

// Virtual methods structure
struct _jc_soot_dava_internal_SET_SETIfElseNode$vmethods {
	struct _jc_soot_dava_internal_AST_ASTNode$object	*(*emit__5fAST$9abd6bb299fe14c5)(_jc_env *, struct _jc_soot_dava_internal_SET_SETIfElseNode$object *);
	struct _jc_soot_util_IterableSet$object	*(*get__5fNaturalExits$93615053d2db173e)(_jc_env *, struct _jc_soot_dava_internal_SET_SETIfElseNode$object *);
};

// Vtable
struct _jc_soot_dava_internal_SET_SETIfElseNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_dava_internal_SET_SETNode$vmethods	soot_dava_internal_SET_SETNode;
	_jc_soot_dava_internal_SET_SETControlFlowNode$vmethods	soot_dava_internal_SET_SETControlFlowNode;
	_jc_soot_dava_internal_SET_SETDagNode$vmethods	soot_dava_internal_SET_SETDagNode;
	_jc_soot_dava_internal_SET_SETIfElseNode$vmethods	soot_dava_internal_SET_SETIfElseNode;
};

// Vtype
struct _jc_soot_dava_internal_SET_SETIfElseNode$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_SET_SETIfElseNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_SET_SETIfElseNode$sub_refs {
	struct _jc_soot_util_IterableSet$object	*ifBody;
	struct _jc_soot_util_IterableSet$object	*elseBody;
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_SET_SETIfElseNode$refs {
    _jc_soot_dava_internal_SET_SETIfElseNode$sub_refs	soot_dava_internal_SET_SETIfElseNode;
    _jc_soot_dava_internal_SET_SETDagNode$sub_refs	soot_dava_internal_SET_SETDagNode;
    _jc_soot_dava_internal_SET_SETControlFlowNode$sub_refs	soot_dava_internal_SET_SETControlFlowNode;
    _jc_soot_dava_internal_SET_SETNode$sub_refs	soot_dava_internal_SET_SETNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_SET_SETIfElseNode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_SET_SETIfElseNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_dava_internal_SET_SETNode$sub_nonrefs	soot_dava_internal_SET_SETNode;
    _jc_soot_dava_internal_SET_SETControlFlowNode$sub_nonrefs	soot_dava_internal_SET_SETControlFlowNode;
    _jc_soot_dava_internal_SET_SETDagNode$sub_nonrefs	soot_dava_internal_SET_SETDagNode;
    _jc_soot_dava_internal_SET_SETIfElseNode$sub_nonrefs	soot_dava_internal_SET_SETIfElseNode;
};

// Object instance structure
struct _jc_soot_dava_internal_SET_SETIfElseNode$object {
	_jc_soot_dava_internal_SET_SETIfElseNode$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_SET_SETIfElseNode$vtype	*vtype;
	_jc_soot_dava_internal_SET_SETIfElseNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_SET_SETIfElseNode$vtype _jc_soot_dava_internal_SET_SETIfElseNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_SET_SETIfElseNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_SET_SETIfElseNode$class_object;

#endif	/* _JC_soot_dava_internal_SET_SETIfElseNode_H_ */

==> jc-1.4.6.tar.gz: soot/dava/internal/SET/SETIfElseNode.h <==
// public class soot.dava.internal.SET.SETIfElseNode

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5fe8043c911a8f07 soot_dava_internal_SET_SETControlFlowNode
// @dep_class 1df4134650bc1e83 soot_dava_internal_SET_SETDagNode
// @dep_class 847c84439c35c0f soot_dava_internal_SET_SETIfElseNode
// @dep_class 4d3d060182af30b5 soot_dava_internal_SET_SETNode

// header file dependencies
// @dep_header soot_dava_internal_SET_SETDagNode

#include "soot/dava/internal/SET/SETDagNode.h"

#ifndef _JC_soot_dava_internal_SET_SETIfElseNode_H_
#define _JC_soot_dava_internal_SET_SETIfElseNode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_dava_internal_AST_ASTNode$object;
struct _jc_soot_dava_internal_asg_AugmentedStmt$object;
struct _jc_soot_util_IterableSet$object;

// Typedefs
typedef struct _jc_soot_dava_internal_SET_SETIfElseNode$sub_refs	_jc_soot_dava_internal_SET_SETIfElseNode$sub_refs;
typedef struct _jc_soot_dava_internal_SET_SETIfElseNode$sub_nonrefs	_jc_soot_dava_internal_SET_SETIfElseNode$sub_nonrefs;
typedef struct _jc_soot_dava_internal_SET_SETIfElseNode$refs	_jc_soot_dava_internal_SET_SETIfElseNode$refs;
typedef struct _jc_soot_dava_internal_SET_SETIfElseNode$nonrefs	_jc_soot_dava_internal_SET_SETIfElseNode$nonrefs;
typedef struct _jc_soot_dava_internal_SET_SETIfElseNode$object	_jc_soot_dava_internal_SET_SETIfElseNode$object;

typedef const struct _jc_soot_dava_internal_SET_SETIfElseNode$vmethods	_jc_soot_dava_internal_SET_SETIfElseNode$vmethods;
typedef const struct _jc_soot_dava_internal_SET_SETIfElseNode$vtable	_jc_soot_dava_internal_SET_SETIfElseNode$vtable;
typedef const struct _jc_soot_dava_internal_SET_SETIfElseNode$vtype	_jc_soot_dava_internal_SET_SETIfElseNode$vtype;

// Constructors
extern void _jc_soot_dava_internal_SET_SETIfElseNode$method$_init$bff09806e2e9995e(_jc_env *, struct _jc_soot_dava_internal_SET_SETIfElseNode$object *, struct _jc_soot_dava_internal_asg_AugmentedStmt$object *, struct _jc_soot_util_IterableSet$object *, struct _jc_soot_util_IterableSet$object *, struct _jc_soot_util_IterableSet$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_soot_dava_internal_AST_ASTNode$object *_jc_soot_dava_internal_SET_SETIfElseNode$method$emit__5fAST$9abd6bb299fe14c5(_jc_env *, struct _jc_soot_dava_internal_SET_SETIfElseNode$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_util_IterableSet$object *_jc_soot_dava_internal_SET_SETIfElseNode$method$get__5fNaturalExits$93615053d2db173e(_jc_env *, struct _jc_soot_dava_internal_SET_SETIfElseNode$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_SET_SETIfElseNode$method_info$emit__5fAST$9abd6bb299fe14c5;
extern _jc_method _jc_soot_dava_internal_SET_SETIfElseNode$method_info$get__5fNaturalExits$93615053d2db173e;

// Virtual methods structure
struct _jc_soot_dava_internal_SET_SETIfElseNode$vmethods {
	struct _jc_soot_dava_internal_AST_ASTNode$object	*(*emit__5fAST$9abd6bb299fe14c5)(_jc_env *, struct _jc_soot_dava_internal_SET_SETIfElseNode$object *) _JC_JCNI_ATTR;
	struct _jc_soot_util_IterableSet$object	*(*get__5fNaturalExits$93615053d2db173e)(_jc_env *, struct _jc_soot_dava_internal_SET_SETIfElseNode$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_dava_internal_SET_SETIfElseNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_dava_internal_SET_SETNode$vmethods	soot_dava_internal_SET_SETNode;
	_jc_soot_dava_internal_SET_SETControlFlowNode$vmethods	soot_dava_internal_SET_SETControlFlowNode;
	_jc_soot_dava_internal_SET_SETDagNode$vmethods	soot_dava_internal_SET_SETDagNode;
	_jc_soot_dava_internal_SET_SETIfElseNode$vmethods	soot_dava_internal_SET_SETIfElseNode;
};

// Vtype
struct _jc_soot_dava_internal_SET_SETIfElseNode$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_SET_SETIfElseNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_SET_SETIfElseNode$sub_refs {
	struct _jc_soot_util_IterableSet$object	*ifBody;
	struct _jc_soot_util_IterableSet$object	*elseBody;
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_SET_SETIfElseNode$refs {
    _jc_soot_dava_internal_SET_SETIfElseNode$sub_refs	soot_dava_internal_SET_SETIfElseNode;
    _jc_soot_dava_internal_SET_SETDagNode$sub_refs	soot_dava_internal_SET_SETDagNode;
    _jc_soot_dava_internal_SET_SETControlFlowNode$sub_refs	soot_dava_internal_SET_SETControlFlowNode;
    _jc_soot_dava_internal_SET_SETNode$sub_refs	soot_dava_internal_SET_SETNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_SET_SETIfElseNode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_SET_SETIfElseNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_dava_internal_SET_SETNode$sub_nonrefs	soot_dava_internal_SET_SETNode;
    _jc_soot_dava_internal_SET_SETControlFlowNode$sub_nonrefs	soot_dava_internal_SET_SETControlFlowNode;
    _jc_soot_dava_internal_SET_SETDagNode$sub_nonrefs	soot_dava_internal_SET_SETDagNode;
    _jc_soot_dava_internal_SET_SETIfElseNode$sub_nonrefs	soot_dava_internal_SET_SETIfElseNode;
};

// Object instance structure
struct _jc_soot_dava_internal_SET_SETIfElseNode$object {
	_jc_soot_dava_internal_SET_SETIfElseNode$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_SET_SETIfElseNode$vtype	*vtype;
	_jc_soot_dava_internal_SET_SETIfElseNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_SET_SETIfElseNode$vtype _jc_soot_dava_internal_SET_SETIfElseNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_SET_SETIfElseNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_SET_SETIfElseNode$class_object;

#endif	/* _JC_soot_dava_internal_SET_SETIfElseNode_H_ */
